@@ -139,6 +139,10 @@ where
             err.emit(handler, &[&self.key_span], &self.names);
         }
 
+        for err in Self::post_process(self.hir, &self.node_key, &tt) {
+            err.emit(handler, &[&self.key_span], &self.names);
+        }
+
         if handler.contains_error() {
             return None;
         }
@@ -156,8 +160,8 @@ where
             Literal::Str(_) => AbstractValueType::String,
             Literal::Bool(_) => AbstractValueType::Bool,
             Literal::Integer(_) => AbstractValueType::Integer,
-            Literal::SInt(_) => AbstractValueType::SInteger(1),
-            Literal::Float(_) => AbstractValueType::Float(1),
+            Literal::SInt(_) => AbstractValueType::SInteger,
+            Literal::Float(_) => AbstractValueType::Float,
         }
     }
 
@@ -205,17 +209,26 @@ where
                 self.tyc
                     .impose(target.concretizes_explicit(AbstractValueType::String))?
             },
+            AnnotatedType::Int(0) => {
+                self.tyc
+                    .impose(target.concretizes_explicit(AbstractValueType::SInteger))?
+            },
             AnnotatedType::Int(x) => {
                 self.tyc
-                    .impose(target.concretizes_explicit(AbstractValueType::SInteger(*x)))?
+                    .impose(target.concretizes_explicit(AbstractValueType::SizedSInteger(*x)))?
             },
+            AnnotatedType::Float(0) => self.tyc.impose(target.concretizes_explicit(AbstractValueType::Float))?,
             AnnotatedType::Float(f) => {
                 self.tyc
-                    .impose(target.concretizes_explicit(AbstractValueType::Float(*f)))?
+                    .impose(target.concretizes_explicit(AbstractValueType::SizedFloat(*f)))?
+            },
+            AnnotatedType::UInt(0) => {
+                self.tyc
+                    .impose(target.concretizes_explicit(AbstractValueType::UInteger))?
             },
             AnnotatedType::UInt(u) => {
                 self.tyc
-                    .impose(target.concretizes_explicit(AbstractValueType::UInteger(*u)))?
+                    .impose(target.concretizes_explicit(AbstractValueType::SizedUInteger(*u)))?
             },
             AnnotatedType::Bool => self.tyc.impose(target.concretizes_explicit(AbstractValueType::Bool))?,
             AnnotatedType::Bytes => self.tyc.impose(target.concretizes_explicit(AbstractValueType::Bytes))?,
@@ -488,7 +501,7 @@ where
                                 self.tyc
                                     .impose(target_key.concretizes_explicit(AbstractValueType::Any))?;
                                 self.tyc
-                                    .impose(term_key.concretizes_explicit(AbstractValueType::UInteger(1)))?;
+                                    .impose(term_key.concretizes_explicit(AbstractValueType::UInteger))?;
                             },
                             //integral :T <T:Num> -> T
                             //integral : T <T:Num> -> Float   <-- currently used
@@ -501,11 +514,11 @@ where
                                     let inner_key = self.tyc.get_child_key(term_key, 0)?;
                                     //self.tyc.impose(inner_key.equate_with(ex_key))?;
                                     self.tyc
-                                        .impose(inner_key.concretizes_explicit(AbstractValueType::Float(1)))?;
+                                        .impose(inner_key.concretizes_explicit(AbstractValueType::Float))?;
                                 } else {
                                     //self.tyc.impose(term_key.concretizes(ex_key))?;
                                     self.tyc
-                                        .impose(term_key.concretizes_explicit(AbstractValueType::Float(1)))?;
+                                        .impose(term_key.concretizes_explicit(AbstractValueType::Float))?;
                                 }
                             },
                             //Σ and Π :T <T:Num> -> T
@@ -686,9 +699,9 @@ where
                 // Bind expr type to least restrictive version of the variant i.e. e.g. Integer w/ width of 1 bit.
                 // Also bind the result to the type annotation of the widening call.
                 let upper_bound = match ty {
-                    AnnotatedType::UInt(_) => AbstractValueType::UInteger(1),
-                    AnnotatedType::Int(_) => AbstractValueType::SInteger(1),
-                    AnnotatedType::Float(_) => AbstractValueType::Float(1),
+                    AnnotatedType::UInt(_) => AbstractValueType::UInteger,
+                    AnnotatedType::Int(_) => AbstractValueType::SInteger,
+                    AnnotatedType::Float(_) => AbstractValueType::Float,
                     _ => unimplemented!("unsupported widening type"),
                 };
                 self.handle_annotated_type(term_key, &ty, Some(inner_expr_key))?;
@@ -826,6 +839,27 @@ where
             })
             .collect()
     }
+
+    pub(crate) fn post_process(
+        hir: &Hir<M>,
+        node_key: &HashMap<NodeId, TcKey>,
+        tt: &TypeTable<AbstractValueType>,
+    ) -> Vec<TypeError<ValueErrorKind>> {
+        let mut errors = vec![];
+        //Check that no output has an optional type
+        for output in &hir.outputs {
+            let key = node_key[&NodeId::SRef(output.sr())];
+            let ty: &ConcreteValueType = &tt[&key];
+            if matches!(ty, ConcreteValueType::Option(_)) {
+                errors.push(TypeError {
+                    kind: ValueErrorKind::OptionNotAllowed(ty.clone()),
+                    key1: Some(key),
+                    key2: None,
+                });
+            }
+        }
+        errors
+    }
 }
 
 #[cfg(test)]
@@ -837,7 +871,7 @@ mod value_type_tests {
     use rtlola_parser::{parse_with_handler, ParserConfig};
     use rtlola_reporting::Handler;
 
-    use crate::hir::{RtLolaHir, StreamReference};
+    use crate::hir::{ExprId, RtLolaHir, StreamReference};
     use crate::modes::BaseMode;
     use crate::type_check::rtltc::{LolaTypeChecker, NodeId};
     use crate::type_check::ConcreteValueType;
@@ -1445,14 +1479,13 @@ output o_9: Bool @i_0 := true  && true";
 
     #[test]
     fn test_optional_type() {
-        let spec = "input in: Int8\noutput out: Int8? := in.offset(by: -1)";
+        let spec = "input in: Int8\noutput out: Int8 := in.offset(by: -1).defaults(to: 0)";
         let (tb, result_map) = check_value_type(spec);
         let in_id = tb.input("in");
-        let out_id = tb.output("out");
         assert_eq!(0, complete_check(spec));
         assert_eq!(result_map[&NodeId::SRef(in_id)], ConcreteValueType::Integer8);
         assert_eq!(
-            result_map[&NodeId::SRef(out_id)],
+            result_map[&NodeId::Expr(ExprId(1))],
             ConcreteValueType::Option(ConcreteValueType::Integer8.into())
         );
     }
@@ -1820,4 +1853,56 @@ output o_9: Bool @i_0 := true  && true";
         let tb = check_expect_error(spec);
         assert_eq!(1, tb.handler.emitted_errors());
     }
+
+    #[test]
+    fn test_sqrt() {
+        let spec = "import math\ninput a: Float32\noutput b := sqrt(a)";
+        let (tb, result_map) = check_value_type(spec);
+        let out_id = tb.output("b");
+        assert_eq!(0, complete_check(spec));
+        assert_eq!(result_map[&NodeId::SRef(out_id)], ConcreteValueType::Float32);
+    }
+
+    #[test]
+    fn test_generics() {
+        let spec = "import math\nconstant x: Float32 := 5.0\noutput b @1Hz := abs(x)";
+        let (tb, result_map) = check_value_type(spec);
+        let out_id = tb.output("b");
+        assert_eq!(0, complete_check(spec));
+        assert_eq!(result_map[&NodeId::SRef(out_id)], ConcreteValueType::Float32);
+    }
+
+    #[test]
+    fn test_complex_spec() {
+        let spec = "\
+        import math\n\
+        input w_dir: Float64\n\
+        input lat: Float64\n\
+        input lon: Float64\n\
+
+        output lon_diff: Float64 := lon - lon.offset(by: -1).defaults(to: lon)\n\
+        output lat_diff: Float64 := lat - lat.offset(by: -1).defaults(to: lat)\n\
+
+        output yaw: Float64 := if lon_diff = 0.0 then 0.0 else arctan(lat_diff / lon_diff)\n\
+        output head_wind: Bool @ 1Hz := (w_dir.hold().defaults(to: 0.0) - yaw.hold().defaults(to: 0.0)) < 0.2";
+        assert_eq!(0, complete_check(spec));
+    }
+
+    #[test]
+    fn test_stdlib_function() {
+        let spec = "import math\n\
+                        input  a : Float64\n\
+                        output b : Float64 := arctan(a)\n\
+                        output c : Float64 := sin(a)\n\
+                        ";
+        assert_eq!(0, complete_check(spec));
+    }
+
+    #[test]
+    fn test_no_optional_stream() {
+        let spec = "input  a : Float64\n\
+                         output b := a.offset(by:-1)";
+        let tb = check_expect_error(spec);
+        assert_eq!(1, tb.handler.emitted_errors());
+    }
 }
